==> com.liferay.frontend.editor.tinymce.web-4.0.0.jar: META-INF/resources/tiny_mce/langs/fi.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

tinymce.addI18n('fi', {
	Cut: 'Leikkaa',
	'Heading 5': 'Otsikko 5',
	'Header 2': 'Otsikko 2',
	"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X/C/V keyboard shortcuts instead.":
		'Selaimesi ei tue leikep\u00f6yd\u00e4n suoraa k\u00e4ytt\u00e4mist\u00e4. Ole hyv\u00e4 ja k\u00e4yt\u00e4 n\u00e4pp\u00e4imist\u00f6n Ctrl+X/C/V n\u00e4pp\u00e4inyhdistelmi\u00e4.',
	'Heading 4': 'Otsikko 4',
	Div: 'Div',
	'Heading 2': 'Otsikko 2',
	Paste: 'Liit\u00e4',
	Close: 'Sulje',
	'Font Family': 'Fontti',
	Pre: 'Esimuotoiltu',
	'Align right': 'Tasaa oikealle',
	'New document': 'Uusi dokumentti',
	Blockquote: 'Lainauslohko',
	'Numbered list': 'J\u00e4rjestetty lista',
	'Heading 1': 'Otsikko 1',
	Headings: 'Otsikot',
	'Increase indent': 'Loitonna',
	Formats: 'Muotoilut',
	Headers: 'Otsikot',
	'Select all': 'Valitse kaikki',
	'Header 3': 'Otsikko 3',
	Blocks: 'Lohkot',
	Undo: 'Peru',
	Strikethrough: 'Yliviivaus',
	'Bullet list': 'J\u00e4rjest\u00e4m\u00e4t\u00f6n lista',
	'Header 1': 'Otsikko 1',
	Superscript: 'Yl\u00e4indeksi',
	'Clear formatting': 'Poista muotoilu',
	'Font Sizes': 'Fonttikoko',
	Subscript: 'Alaindeksi',
	'Header 6': 'Otsikko 6',
	Redo: 'Tee uudelleen',
	Paragraph: 'Kappale',
	Ok: 'Ok',
	Bold: 'Lihavointi',
	Code: 'Koodi',
	Italic: 'Kursivointi',
	'Align center': 'Keskit\u00e4',
	'Header 5': 'Otsikko 5',
	'Heading 6': 'Otsikko 6',
	'Heading 3': 'Otsikko 3',
	'Decrease indent': 'Sisenn\u00e4',
	'Header 4': 'Otsikko 4',
	'Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.':
		'Liitt\u00e4minen on nyt pelk\u00e4n tekstin -tilassa. Sis\u00e4ll\u00f6t liitet\u00e4\u00e4n nyt pelkk\u00e4n\u00e4 tekstin\u00e4, kunnes otat vaihtoehdon pois k\u00e4yt\u00f6st\u00e4.',
	Underline: 'Alleviivaus',
	Cancel: 'Peruuta',
	Justify: 'Tasaa',
	Inline: 'Samalla rivill\u00e4',
	Copy: 'Kopioi',
	'Align left': 'Tasaa vasemmalle',
	'Visual aids': 'Visuaaliset neuvot',
	'Lower Greek': 'pienet kirjaimet: \u03b1, \u03b2, \u03b3',
	Square: 'Neli\u00f6',
	Default: 'Oletus',
	'Lower Alpha': 'pienet kirjaimet: a, b, c',
	Circle: 'Pallo',
	Disc: 'Ympyr\u00e4',
	'Upper Alpha': 'isot kirjaimet: A, B, C',
	'Upper Roman': 'isot kirjaimet: I, II, III',
	'Lower Roman': 'pienet kirjaimet: i, ii, iii',
	Name: 'Nimi',
	Anchor: 'Ankkuri',
	'You have unsaved changes are you sure you want to navigate away?':
		'Sinulla on tallentamattomia muutoksia, haluatko varmasti siirty\u00e4 toiselle sivulle?',
	'Restore last draft': 'Palauta aiempi luonnos',
	'Special character': 'Erikoismerkki',
	'Source code': 'L\u00e4hdekoodi',
	Color: 'V\u00e4ri',
	'Right to left': 'Oikealta vasemmalle',
	'Left to right': 'Vasemmalta oikealle',
	Emoticons: 'Hymi\u00f6t',
	Robots: 'Robotit',
	'Document properties': 'Dokumentin ominaisuudet',
	Title: 'Otsikko',
	Keywords: 'Avainsanat',
	Encoding: 'Merkist\u00f6',
	Description: 'Kuvaus',
	Author: 'Tekij\u00e4',
	Fullscreen: 'Koko ruutu',
	'Horizontal line': 'Vaakasuora viiva',
	'Horizontal space': 'Horisontaalinen tila',
	'Insert/edit image': 'Lis\u00e4\u00e4/muokkaa kuva',
	General: 'Yleiset',
	Advanced: 'Lis\u00e4asetukset',
	Source: 'L\u00e4hde',
	Border: 'Reunus',
	'Constrain proportions': 'S\u00e4ilyt\u00e4 mittasuhteet',
	'Vertical space': 'Vertikaalinen tila',
	'Image description': 'Kuvaus',
	Style: 'Tyyli',
	Dimensions: 'Mittasuhteet',
	'Insert image': 'Lis\u00e4\u00e4 kuva',
	'Insert date/time':
		'Lis\u00e4\u00e4 p\u00e4iv\u00e4m\u00e4\u00e4r\u00e4 tai aika',
	'Remove link': 'Poista linkki',
	Url: 'Osoite',
	'Text to display': 'N\u00e4ytett\u00e4v\u00e4 teksti',
	Anchors: 'Ankkurit',
	'Insert link': 'Lis\u00e4\u00e4 linkki',
	'New window': 'Uusi ikkuna',
	None: 'Ei mit\u00e4\u00e4n',
	'The URL you entered seems to be an external link. Do you want to add the required http:// prefix?':
		'Antamasi osoite n\u00e4ytt\u00e4\u00e4 olevan ulkoinen linkki. Haluatko lis\u00e4t\u00e4 osoitteeseen vaaditun http:// -etuliitteen?',
	Target: 'Kohde',
	'The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?':
		'Antamasi osoite n\u00e4ytt\u00e4\u00e4 olevan s\u00e4hk\u00f6postiosoite. Haluatko lis\u00e4t\u00e4 osoitteeseen vaaditun mailto: -etuliitteen?',
	'Insert/edit link': 'Lis\u00e4\u00e4 tai muokkaa linkki',
	'Insert/edit video': 'Lis\u00e4\u00e4/muokkaa video',
	Poster: 'L\u00e4hett\u00e4j\u00e4',
	'Alternative source': 'Vaihtoehtoinen l\u00e4hde',
	'Paste your embed code below:': 'Liit\u00e4 upotuskoodisi alapuolelle:',
	'Insert video': 'Lis\u00e4\u00e4 video',
	Embed: 'Upota',
	'Nonbreaking space': 'Sitova v\u00e4lily\u00f6nti',
	'Page break': 'Sivunvaihto',
	'Paste as text': 'Liit\u00e4 tekstin\u00e4',
	Preview: 'Esikatselu',
	Print: 'Tulosta',
	Save: 'Tallenna',
	'Could not find the specified string.':
		'Haettua merkkijonoa ei l\u00f6ytynyt.',
	Replace: 'Korvaa',
	Next: 'Seur.',
	'Whole words': 'Koko sanat',
	'Find and replace': 'Etsi ja korvaa',
	'Replace with': 'Korvaa',
	Find: 'Etsi',
	'Replace all': 'Korvaa kaikki',
	'Match case': 'Erota isot ja pienet kirjaimet',
	Prev: 'Edel.',
	Spellcheck: 'Oikolue',
	Finish: 'Lopeta',
	'Ignore all': '\u00c4l\u00e4 huomioi mit\u00e4\u00e4n',
	Ignore: '\u00c4l\u00e4 huomioi',
	'Add to Dictionary': 'Lis\u00e4\u00e4 sanakirjaan',
	'Insert row before': 'Lis\u00e4\u00e4 rivi ennen',
	Rows: 'Rivit',
	Height: 'Korkeus',
	'Paste row after': 'Liit\u00e4 rivi j\u00e4lkeen',
	Alignment: 'Tasaus',
	'Border color': 'Reunuksen v\u00e4ri',
	'Column group': 'Sarakeryhm\u00e4',
	Row: 'Rivi',
	'Insert column before': 'Lis\u00e4\u00e4 rivi ennen',
	'Split cell': 'Jaa solu',
	'Cell padding': 'Solun tyhj\u00e4 tila',
	'Cell spacing': 'Solun v\u00e4li',
	'Row type': 'Rivityyppi',
	'Insert table': 'Lis\u00e4\u00e4 taulukko',
	Body: 'Runko',
	Caption: 'Seloste',
	Footer: 'Alaosa',
	'Delete row': 'Poista rivi',
	'Paste row before': 'Liit\u00e4 rivi ennen',
	Scope: 'Laajuus',
	'Delete table': 'Poista taulukko',
	'H Align': 'H tasaus',
	Top: 'Yl\u00e4reuna',
	'Header cell': 'Otsikkosolu',
	Column: 'Sarake',
	'Row group': 'Riviryhm\u00e4',
	Cell: 'Solu',
	Middle: 'Keskikohta',
	'Cell type': 'Solun tyyppi',
	'Copy row': 'Kopioi rivi',
	'Row properties': 'Rivin ominaisuudet',
	'Table properties': 'Taulukon ominaisuudet',
	Bottom: 'Alareuna',
	'V Align': 'V tasaus',
	Header: 'Otsikko',
	Right: 'Oikea',
	'Insert column after': 'Lis\u00e4\u00e4 rivi j\u00e4lkeen',
	Cols: 'Sarakkeet',
	'Insert row after': 'Lis\u00e4\u00e4 rivi j\u00e4lkeen',
	Width: 'Leveys',
	'Cell properties': 'Solun ominaisuudet',
	Left: 'Vasen',
	'Cut row': 'Leikkaa rivi',
	'Delete column': 'Poista sarake',
	Center: 'Keskell\u00e4',
	'Merge cells': 'Yhdist\u00e4 solut',
	'Insert template': 'Lis\u00e4\u00e4 pohja',
	Templates: 'Pohjat',
	'Background color': 'Taustan v\u00e4ri',
	'Text color': 'Tekstin v\u00e4ri',
	'Show blocks': 'N\u00e4yt\u00e4 lohkot',
	'Show invisible characters':
		'N\u00e4yt\u00e4 n\u00e4kym\u00e4tt\u00f6m\u00e4t merkit',
	'Words: {0}': 'Sanat: {0}',
	Insert: 'Lis\u00e4\u00e4',
	File: 'Tiedosto',
	Edit: 'Muokkaa',
	'Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help':
		'Rikastetun tekstin alue. Paina ALT-F9 valikkoon. Paina ALT-F10 ty\u00f6kaluriviin. Paina ALT-0 ohjeeseen.',
	Tools: 'Ty\u00f6kalut',
	View: 'N\u00e4yt\u00e4',
	Table: 'Taulukko',
	Format: 'Muotoilu'
});

==> com.liferay.frontend.editor.tinymce.web-5.0.12.jar: META-INF/resources/tiny_mce/langs/fi.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

tinymce.addI18n('fi', {
	'Cut': 'Leikkaa',
	'Heading 5': 'Otsikko 5',
	'Header 2': 'Otsikko 2',
	"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X/C/V keyboard shortcuts instead.":
		'Selaimesi ei tue leikep\u00f6yd\u00e4n suoraa k\u00e4ytt\u00e4mist\u00e4. Ole hyv\u00e4 ja k\u00e4yt\u00e4 n\u00e4pp\u00e4imist\u00f6n Ctrl+X/C/V n\u00e4pp\u00e4inyhdistelmi\u00e4.',
	'Heading 4': 'Otsikko 4',
	'Div': 'Div',
	'Heading 2': 'Otsikko 2',
	'Paste': 'Liit\u00e4',
	'Close': 'Sulje',
	'Font Family': 'Fontti',
	'Pre': 'Esimuotoiltu',
	'Align right': 'Tasaa oikealle',
	'New document': 'Uusi dokumentti',
	'Blockquote': 'Lainauslohko',
	'Numbered list': 'J\u00e4rjestetty lista',
	'Heading 1': 'Otsikko 1',
	'Headings': 'Otsikot',
	'Increase indent': 'Loitonna',
	'Formats': 'Muotoilut',
	'Headers': 'Otsikot',
	'Select all': 'Valitse kaikki',
	'Header 3': 'Otsikko 3',
	'Blocks': 'Lohkot',
	'Undo': 'Peru',
	'Strikethrough': 'Yliviivaus',
	'Bullet list': 'J\u00e4rjest\u00e4m\u00e4t\u00f6n lista',
	'Header 1': 'Otsikko 1',
	'Superscript': 'Yl\u00e4indeksi',
	'Clear formatting': 'Poista muotoilu',
	'Font Sizes': 'Fonttikoko',
	'Subscript': 'Alaindeksi',
	'Header 6': 'Otsikko 6',
	'Redo': 'Tee uudelleen',
	'Paragraph': 'Kappale',
	'Ok': 'Ok',
	'Bold': 'Lihavointi',
	'Code': 'Koodi',
	'Italic': 'Kursivointi',
	'Align center': 'Keskit\u00e4',
	'Header 5': 'Otsikko 5',
	'Heading 6': 'Otsikko 6',
	'Heading 3': 'Otsikko 3',
	'Decrease indent': 'Sisenn\u00e4',
	'Header 4': 'Otsikko 4',
	'Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.':
		'Liitt\u00e4minen on nyt pelk\u00e4n tekstin -tilassa. Sis\u00e4ll\u00f6t liitet\u00e4\u00e4n nyt pelkk\u00e4n\u00e4 tekstin\u00e4, kunnes otat vaihtoehdon pois k\u00e4yt\u00f6st\u00e4.',
	'Underline': 'Alleviivaus',
	'Cancel': 'Peruuta',
	'Justify': 'Tasaa',
	'Inline': 'Samalla rivill\u00e4',
	'Copy': 'Kopioi',
	'Align left': 'Tasaa vasemmalle',
	'Visual aids': 'Visuaaliset neuvot',
	'Lower Greek': 'pienet kirjaimet: \u03b1, \u03b2, \u03b3',
	'Square': 'Neli\u00f6',
	'Default': 'Oletus',
	'Lower Alpha': 'pienet kirjaimet: a, b, c',
	'Circle': 'Pallo',
	'Disc': 'Ympyr\u00e4',
	'Upper Alpha': 'isot kirjaimet: A, B, C',
	'Upper Roman': 'isot kirjaimet: I, II, III',
	'Lower Roman': 'pienet kirjaimet: i, ii, iii',
	'Name': 'Nimi',
	'Anchor': 'Ankkuri',
	'You have unsaved changes are you sure you want to navigate away?':
		'Sinulla on tallentamattomia muutoksia, haluatko varmasti siirty\u00e4 toiselle sivulle?',
	'Restore last draft': 'Palauta aiempi luonnos',
	'Special character': 'Erikoismerkki',
	'Source code': 'L\u00e4hdekoodi',
	'Color': 'V\u00e4ri',
	'Right to left': 'Oikealta vasemmalle',
	'Left to right': 'Vasemmalta oikealle',
	'Emoticons': 'Hymi\u00f6t',
	'Robots': 'Robotit',
	'Document properties': 'Dokumentin ominaisuudet',
	'Title': 'Otsikko',
	'Keywords': 'Avainsanat',
	'Encoding': 'Merkist\u00f6',
	'Description': 'Kuvaus',
	'Author': 'Tekij\u00e4',
	'Fullscreen': 'Koko ruutu',
	'Horizontal line': 'Vaakasuora viiva',
	'Horizontal space': 'Horisontaalinen tila',
	'Insert/edit image': 'Lis\u00e4\u00e4/muokkaa kuva',
	'General': 'Yleiset',
	'Advanced': 'Lis\u00e4asetukset',
	'Source': 'L\u00e4hde',
	'Border': 'Reunus',
	'Constrain proportions': 'S\u00e4ilyt\u00e4 mittasuhteet',
	'Vertical space': 'Vertikaalinen tila',
	'Image description': 'Kuvaus',
	'Style': 'Tyyli',
	'Dimensions': 'Mittasuhteet',
	'Insert image': 'Lis\u00e4\u00e4 kuva',
	'Insert date/time':
		'Lis\u00e4\u00e4 p\u00e4iv\u00e4m\u00e4\u00e4r\u00e4 tai aika',
	'Remove link': 'Poista linkki',
	'Url': 'Osoite',
	'Text to display': 'N\u00e4ytett\u00e4v\u00e4 teksti',
	'Anchors': 'Ankkurit',
	'Insert link': 'Lis\u00e4\u00e4 linkki',
	'New window': 'Uusi ikkuna',
	'None': 'Ei mit\u00e4\u00e4n',
	'The URL you entered seems to be an external link. Do you want to add the required http:// prefix?':
		'Antamasi osoite n\u00e4ytt\u00e4\u00e4 olevan ulkoinen linkki. Haluatko lis\u00e4t\u00e4 osoitteeseen vaaditun http:// -etuliitteen?',
	'Target': 'Kohde',
	'The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?':
		'Antamasi osoite n\u00e4ytt\u00e4\u00e4 olevan s\u00e4hk\u00f6postiosoite. Haluatko lis\u00e4t\u00e4 osoitteeseen vaaditun mailto: -etuliitteen?',
	'Insert/edit link': 'Lis\u00e4\u00e4 tai muokkaa linkki',
	'Insert/edit video': 'Lis\u00e4\u00e4/muokkaa video',
	'Poster': 'L\u00e4hett\u00e4j\u00e4',
	'Alternative source': 'Vaihtoehtoinen l\u00e4hde',
	'Paste your embed code below:': 'Liit\u00e4 upotuskoodisi alapuolelle:',
	'Insert video': 'Lis\u00e4\u00e4 video',
	'Embed': 'Upota',
	'Nonbreaking space': 'Sitova v\u00e4lily\u00f6nti',
	'Page break': 'Sivunvaihto',
	'Paste as text': 'Liit\u00e4 tekstin\u00e4',
	'Preview': 'Esikatselu',
	'Print': 'Tulosta',
	'Save': 'Tallenna',
	'Could not find the specified string.':
		'Haettua merkkijonoa ei l\u00f6ytynyt.',
	'Replace': 'Korvaa',
	'Next': 'Seur.',
	'Whole words': 'Koko sanat',
	'Find and replace': 'Etsi ja korvaa',
	'Replace with': 'Korvaa',
	'Find': 'Etsi',
	'Replace all': 'Korvaa kaikki',
	'Match case': 'Erota isot ja pienet kirjaimet',
	'Prev': 'Edel.',
	'Spellcheck': 'Oikolue',
	'Finish': 'Lopeta',
	'Ignore all': '\u00c4l\u00e4 huomioi mit\u00e4\u00e4n',
	'Ignore': '\u00c4l\u00e4 huomioi',
	'Add to Dictionary': 'Lis\u00e4\u00e4 sanakirjaan',
	'Insert row before': 'Lis\u00e4\u00e4 rivi ennen',
	'Rows': 'Rivit',
	'Height': 'Korkeus',
	'Paste row after': 'Liit\u00e4 rivi j\u00e4lkeen',
	'Alignment': 'Tasaus',
	'Border color': 'Reunuksen v\u00e4ri',
	'Column group': 'Sarakeryhm\u00e4',
	'Row': 'Rivi',
	'Insert column before': 'Lis\u00e4\u00e4 rivi ennen',
	'Split cell': 'Jaa solu',
	'Cell padding': 'Solun tyhj\u00e4 tila',
	'Cell spacing': 'Solun v\u00e4li',
	'Row type': 'Rivityyppi',
	'Insert table': 'Lis\u00e4\u00e4 taulukko',
	'Body': 'Runko',
	'Caption': 'Seloste',
	'Footer': 'Alaosa',
	'Delete row': 'Poista rivi',
	'Paste row before': 'Liit\u00e4 rivi ennen',
	'Scope': 'Laajuus',
	'Delete table': 'Poista taulukko',
	'H Align': 'H tasaus',
	'Top': 'Yl\u00e4reuna',
	'Header cell': 'Otsikkosolu',
	'Column': 'Sarake',
	'Row group': 'Riviryhm\u00e4',
	'Cell': 'Solu',
	'Middle': 'Keskikohta',
	'Cell type': 'Solun tyyppi',
	'Copy row': 'Kopioi rivi',
	'Row properties': 'Rivin ominaisuudet',
	'Table properties': 'Taulukon ominaisuudet',
	'Bottom': 'Alareuna',
	'V Align': 'V tasaus',
	'Header': 'Otsikko',
	'Right': 'Oikea',
	'Insert column after': 'Lis\u00e4\u00e4 rivi j\u00e4lkeen',
	'Cols': 'Sarakkeet',
	'Insert row after': 'Lis\u00e4\u00e4 rivi j\u00e4lkeen',
	'Width': 'Leveys',
	'Cell properties': 'Solun ominaisuudet',
	'Left': 'Vasen',
	'Cut row': 'Leikkaa rivi',
	'Delete column': 'Poista sarake',
	'Center': 'Keskell\u00e4',
	'Merge cells': 'Yhdist\u00e4 solut',
	'Insert template': 'Lis\u00e4\u00e4 pohja',
	'Templates': 'Pohjat',
	'Background color': 'Taustan v\u00e4ri',
	'Text color': 'Tekstin v\u00e4ri',
	'Show blocks': 'N\u00e4yt\u00e4 lohkot',
	'Show invisible characters':
		'N\u00e4yt\u00e4 n\u00e4kym\u00e4tt\u00f6m\u00e4t merkit',
	'Words: {0}': 'Sanat: {0}',
	'Insert': 'Lis\u00e4\u00e4',
	'File': 'Tiedosto',
	'Edit': 'Muokkaa',
	'Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help':
		'Rikastetun tekstin alue. Paina ALT-F9 valikkoon. Paina ALT-F10 ty\u00f6kaluriviin. Paina ALT-0 ohjeeseen.',
	'Tools': 'Ty\u00f6kalut',
	'View': 'N\u00e4yt\u00e4',
	'Table': 'Taulukko',
	'Format': 'Muotoilu',
});
